@@ -1,4 +1,4 @@
 """Arrrgs library"""
 from .command import command, no_command
 from .arguments import arg, global_args
-from .run import run
+from .run import run, async_run
